pub struct ObjectPinV0 {
pub id: ObjectId,
}Expand description
Request to pin an object
Brokers maintain an LRU cache of objects, where old, unused objects might get deleted to free up space for new ones. Pinned objects are retained, regardless of last access.
Fields
id: ObjectIdTrait Implementations
Sourceimpl Clone for ObjectPinV0
impl Clone for ObjectPinV0
Sourcefn clone(&self) -> ObjectPinV0
fn clone(&self) -> ObjectPinV0
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ObjectPinV0
Sourceimpl Debug for ObjectPinV0
impl Debug for ObjectPinV0
Sourceimpl<'de> Deserialize<'de> for ObjectPinV0
impl<'de> Deserialize<'de> for ObjectPinV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more